# eric7.Plugins.VcsPlugins.vcsGit.GitPushDialog

Module implementing a dialog to enter data for a Push operation.

### Global Attributes

None

### Classes

GitPushDialog | Class implementing a dialog to enter data for a Push operation.

### Functions

None

## GitPushDialog

Class implementing a dialog to enter data for a Push operation.

### Derived from

QDialog, Ui_GitPushDialog

### Class Attributes

ForceColumn
LocalBranchColumn
PushColumn
RemoteBranchColumn

### Class Methods

None

### Methods

GitPushDialog | Constructor
__resizeColumns | Private slot to adjust the column sizes.
getData | Public method to get the entered data.
on_branchesTree_itemChanged | Private slot handling changes of a branch item.
on_remotesComboBox_currentTextChanged | Private slot to handle changes of the selected repository.
on_selectAllCheckBox_stateChanged | Private slot to select/deselect all branch items.

### Static Methods

None

#### GitPushDialog (Constructor)

GitPushDialog(vcs, repodir, parent=None)

Constructor

vcs (Git)
  reference to the git object
repodir (str)
  directory name of the local repository
parent (QWidget)
  reference to the parent widget

#### GitPushDialog.__resizeColumns

__resizeColumns()

Private slot to adjust the column sizes.

#### GitPushDialog.getData

getData()

Public method to get the entered data.

Return:
  remote name, list of branches to be pushed, a flag indicating to push tags as well, a flag indicating to set tracking information and the push method for submodules

Return Type:
  tuple of (str, list of str, bool, bool, str)

#### GitPushDialog.on_branchesTree_itemChanged

on_branchesTree_itemChanged(item, column)

Private slot handling changes of a branch item.

item (QTreeWidgetItem)
  reference to the changed item
column (int)
  changed column

#### GitPushDialog.on_remotesComboBox_currentTextChanged

on_remotesComboBox_currentTextChanged(txt)

Private slot to handle changes of the selected repository.

txt (str)
  current text of the combo box

#### GitPushDialog.on_selectAllCheckBox_stateChanged

on_selectAllCheckBox_stateChanged(state)

Private slot to select/deselect all branch items.

state (Qt.CheckState)
  check state of the check box

Up